@@ -1,6 +1,6 @@
 "postMDS" <-
-function (X, dist, pc = TRUE, center = TRUE, halfchange = TRUE, 
-    threshold = 0.8, nthreshold = 10, plot = FALSE) 
+    function (X, dist, pc = TRUE, center = TRUE, halfchange = TRUE, 
+              threshold = 0.8, nthreshold = 10, plot = FALSE) 
 {
     Size <- attributes(dist)$Size
     if (any(attributes(X)$names == "points")) 
@@ -17,12 +17,15 @@ function (X, dist, pc = TRUE, center = TRUE, halfchange = TRUE,
         dist <- as.vector(dist)
         ordi <- as.vector(vegdist(x, "euclidean"))
         take <- dist < threshold
-        if (sum(take) < nthreshold) 
-            stop("Too few data points for half-change scaling")
-        k <- coef(lm(dist[take] ~ ordi[take]))
-        names(k) <- NULL
-        hc <- (1 - k[1])/2/k[2]
-        x <- x/hc
+        if (sum(take) < nthreshold) { 
+            warning("skipping half-change scaling: too few points below threshold")
+            halfchange <- FALSE
+        } else {
+            k <- coef(lm(dist[take] ~ ordi[take]))
+            names(k) <- NULL
+            hc <- (1 - k[1])/2/k[2]
+            x <- x/hc
+        }
     }
     if (plot && halfchange) {
         cross.lim <- 45
@@ -32,7 +35,7 @@ function (X, dist, pc = TRUE, center = TRUE, halfchange = TRUE,
         orange <- range(c(ordi, 0, 1))
         drange <- range(c(dist, 0, 1))
         plot(orange, drange, type = "n", xlab = "Ordination distance", 
-            ylab = "Community dissimilarity")
+             ylab = "Community dissimilarity")
         points(ordi[take], dist[take], pch = pch, col = "blue")
         points(ordi[!take], dist[!take], pch = pch, col = "gray")
         abline(h = threshold)
@@ -45,12 +48,15 @@ function (X, dist, pc = TRUE, center = TRUE, halfchange = TRUE,
         j <- 0.02
         text(0 + j, threshold + j, "Threshold", adj = c(0, 0))
         text(0 + j, k[1] + j, "Replicate dissimilarity", adj = c(0, 
-            0))
+                                                         0))
         text(0 + j, hclevel + j, "Half-change", adj = c(0, 0))
         abline(k, col = "blue", lwd = 2)
     }
     if (any(attributes(X)$names == "points")) 
         X$points <- x
     else X <- x
+    attr(X, "centre") <- center
+    attr(X, "pc") <- pc
+    attr(X, "halfchange") <- halfchange
     X
 }
